"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MySQLComponent = void 0;
const pulumi = require("@pulumi/pulumi");
const gcp = require("@pulumi/gcp");
const utils_1 = require("../libs/utils");
class MySQLComponent extends pulumi.ComponentResource {
    constructor(name, args, opts = {}) {
        super('wordpress:mysql', name, {}, opts);
        this.instance = new gcp.sql.DatabaseInstance(name, {
            name: utils_1.escapeName(name),
            databaseVersion: args.databaseVersion,
            deletionProtection: false,
            settings: {
                availabilityType: args.availabilityType,
                backupConfiguration: {
                    enabled: args.enableBackups || false,
                },
                diskAutoresize: true,
                diskSize: args.diskSize,
                diskType: 'PD_SSD',
                tier: args.tier || 'db-f1-micro',
            },
        }, { parent: this });
        this.database = new gcp.sql.Database(name, {
            name: utils_1.escapeName(name, 5, 16),
            instance: this.instance.name,
        }, { parent: this });
        this.user = new gcp.sql.User(name, {
            instance: this.instance.name,
            name: utils_1.escapeName(name, 5, 16),
        }, { parent: this });
    }
}
exports.MySQLComponent = MySQLComponent;
